from conan import ConanFile
from conan.tools.cmake import CMakeToolchain, CMake, cmake_layout, CMakeDeps


class AcquireWaveformLecroyRecipe(ConanFile):
    name = "acquirewaveformlecroy"
    executable = "ds_AcquireWaveformLecroy"
    version = "1.2.0"
    package_type = "application"
    user = "soleil"

    license = "GPL-3.0-or-later"
    author = "Xavier Elattaoui"
    url = "https://gitlab.synchrotron-soleil.fr/software-control-system/tango-devices/measureinstruments/lecroy/acquirewaveformlecroy.git"
    description = "AcquireWaveformLecroy device"
    topics = ("control-system", "tango", "device")

    settings = "os", "compiler", "build_type", "arch"

    exports_sources = "CMakeLists.txt", "src/*", "include/*"
    
    def requirements(self):
        self.requires("yat4tango/[>=1.0]@soleil/stable")
        if self.settings.os == "Linux":
            self.requires("crashreporting2/[>=1.0]@soleil/stable")
    
    def layout(self):
        cmake_layout(self)

    def generate(self):
        deps = CMakeDeps(self)
        deps.generate()
        tc = CMakeToolchain(self)
        tc.variables["PROJECT_NAME"] = self.name
        tc.variables["PROJECT_VERSION"] = self.version
        tc.variables["EXECUTABLE_NAME"] = self.executable
        tc.generate()

    def build(self):
        cmake = CMake(self)
        cmake.configure()
        cmake.build()

    def package(self):
        cmake = CMake(self)
        cmake.install()
